#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2022/6/20 10:36
# @Author  : lj
# @File    : __init__.py.py
from .singleton import Singleton
__all__=[
    'Singleton'
]